@@ -1,6 +1,7 @@
 import numpy as np
 import inflect
 from scipy.stats import iqr
+from math import floor, log
 
 
 class PandasTransformFuncs:
@@ -26,15 +27,24 @@ class PandasTransformFuncs:
 
 
 class HumanReadableTextFormatting:
-    @staticmethod
-    def format_col(x, method):
+    @classmethod
+    def format_col(cls, x, method):
         if method == 'dollar':
             return f'${round(x):,}'
+        if method == 'dollar-short':
+            return f'${cls._longnum2string(x)}'
         if method == 'percent':
             return f'{round(x*1000)/10}%'
         if method == 'inflect':
             return inflect.engine().number_to_words(x)
 
+    @staticmethod
+    def _longnum2string(x):
+        units = ['', 'K', 'M', 'G', 'T', 'P']
+        k = 1000.0
+        magnitude = int(floor(log(x, k)))
+        return f'{round(x / k**magnitude)}{units[magnitude]}'
+
     @staticmethod
     def html_text_augment(x, methods):
         tags = {
@@ -145,35 +155,38 @@ def add_grid_update_yaxis(fig, idx):
     fig_data = fig.data[idx]
     n_bars = len(fig_data.x)
     ymin, ymax, step = get_new_axis_range(fig_data.y)
-    tick_steps = np.arange(ymin, ymax, step)
-    tick_steps = downsample_steps(tick_steps, ymax)
 
-    # probably no need to cap ymax, just keep it at original calculated ymax
-    # ymax=cap_ymax(ymax, tick_steps, fig_data.y)
-    print('yaxis details:')
-    print(ymin, ymax)
-    print(tick_steps)
+    # exception for very small range values
+    if step > 0:
+        tick_steps = np.arange(ymin, ymax, step)
+        tick_steps = downsample_steps(tick_steps, ymax)
 
-    fig.update_yaxes(
-        tickmode='array',
-        tickvals=tick_steps,
-        range=[ymin, ymax],
-        row=idx+1, col=1
-    )
+        # probably no need to cap ymax, just keep it at original calculated ymax
+        # ymax=cap_ymax(ymax, tick_steps, fig_data.y)
+        print('yaxis details:')
+        print(ymin, ymax)
+        print(tick_steps)
 
-    # dont draw line for first tick
-    for y in tick_steps[1:]:
-        fig.add_shape(type="line",
-                      xref='paper', x0=-0.5, y0=y, x1=n_bars-0.5, y1=y,
-                      line=dict(
-                          color="#C8CDD5",
-                          width=1.5,
-                          dash="dot",
+        fig.update_yaxes(
+            tickmode='array',
+            tickvals=tick_steps,
+            range=[ymin, ymax],
+            row=idx+1, col=1
+        )
 
-                      ),
-                      layer='below',
-                      row=idx+1, col=1
-                      )
+        # dont draw line for first tick
+        for y in tick_steps[1:]:
+            fig.add_shape(type="line",
+                          xref='paper', x0=-0.5, y0=y, x1=n_bars-0.5, y1=y,
+                          line=dict(
+                              color="#C8CDD5",
+                              width=1.5,
+                              dash="dot",
+
+                          ),
+                          layer='below',
+                          row=idx+1, col=1
+                          )
     return fig
 
 # cap the max value if the maximum tick value is already
